You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@hbase.apache.org by zh...@apache.org on 2020/03/27 02:49:20 UTC

[hbase] branch branch-2.2 updated: HBASE-24050 Deprecated PBType on all 2.x branches (#1354)

This is an automated email from the ASF dual-hosted git repository.

zhangduo pushed a commit to branch branch-2.2
in repository https://gitbox.apache.org/repos/asf/hbase.git


The following commit(s) were added to refs/heads/branch-2.2 by this push:
     new 71b9ca1  HBASE-24050 Deprecated PBType on all 2.x branches (#1354)
71b9ca1 is described below

commit 71b9ca14607b3346a92b1f68ffe0a99fb6460265
Author: Duo Zhang <zh...@apache.org>
AuthorDate: Fri Mar 27 10:43:14 2020 +0800

    HBASE-24050 Deprecated PBType on all 2.x branches (#1354)
    
    Signed-off-by: Jan Hentschel <ja...@ultratendency.com>
    Signed-off-by: Viraj Jasani <vj...@apache.org>
---
 .../src/main/java/org/apache/hadoop/hbase/types/PBType.java       | 8 ++++++--
 1 file changed, 6 insertions(+), 2 deletions(-)

diff --git a/hbase-common/src/main/java/org/apache/hadoop/hbase/types/PBType.java b/hbase-common/src/main/java/org/apache/hadoop/hbase/types/PBType.java
index eb67e71..60ad863 100644
--- a/hbase-common/src/main/java/org/apache/hadoop/hbase/types/PBType.java
+++ b/hbase-common/src/main/java/org/apache/hadoop/hbase/types/PBType.java
@@ -25,9 +25,13 @@ import org.apache.hadoop.hbase.util.PositionedByteRange;
 import org.apache.yetus.audience.InterfaceAudience;
 
 /**
  * A base-class for {@link DataType} implementations backed by protobuf. See
  * {@code PBKeyValue} in {@code hbase-examples} module.
  */
+@Deprecated
 @InterfaceAudience.Public
 public abstract class PBType<T extends Message> implements DataType<T> {
   @Override
@@ -25,9 +25,13 @@ import org.apache.hadoop.hbase.util.PositionedByteRange;
 
 /**
- * A base-class for {@link DataType} implementations backed by protobuf. See
- * {@code PBKeyValue} in {@code hbase-examples} module.
+ * A base-class for {@link DataType} implementations backed by protobuf. See {@code PBKeyValue} in
+ * {@code hbase-examples} module.
+ * @deprecated Will be removed in 3.0.0 without replacement. It should not be a public API as it
+ *             exposes the protobuf stuff. Users who depend on this class should just copy the code
+ *             your own code base.
  */